@@ -337,6 +337,9 @@ def dump_template_fields(_json):
 
 def dump_events(events_json):
     events = []
+    if events_json is None:
+        return events
+
     for event in events_json:
         result = {}
         set_if_not_equal(result, "name", event["name"], None)
