@@ -124,7 +124,6 @@ class Quip:
         parser_icon.add_argument('name', nargs="?", help='name of the project')
 
         parser_icon = subparsers.add_parser('setup', help='Setup External Systems')
-        parser_icon.add_argument('--sonarqube', action='store_true', help='create SonarQube Project')
         parser_icon.add_argument('name', nargs="?", help='name of the project')
 
         parser_icon = subparsers.add_parser('version', help='shows the version of the template/extension')
@@ -701,7 +700,7 @@ class Quip:
             jnks_groups = jnks_config.get("groups", {})
             jnks_group_name, jnks_repository_name = external.parse_repository_full_path(repository_name, gl_groups, jnks_groups)
             
-            self.setup_jenkins(jnks, jnks_group_name, jnks_repository_name)
+            self.setup_jenkins(jnks, jnks_group_name, jnks_repository_name, gl.base_url)
             
         # create webhook for Jenkins
         if gl_config is not None and jnks_config is not None:
@@ -742,14 +741,14 @@ class Quip:
         gl.repository_name = repository_name
         return gl
     
-    def setup_jenkins(self, jnks, jnks_group_name, jnks_repository_name):
+    def setup_jenkins(self, jnks, jnks_group_name, jnks_repository_name, gitlab_url):
         # Check if Jenkins Pipeline exists
         if jnks.check_job_exists(jnks_group_name, jnks_repository_name):
             cprint(f"Job exists in Jenkins: {jnks_group_name}/{jnks_repository_name}", "magenta")
         else:
             logging.info(f"Repository doesn't exist and will be created. {jnks_group_name}/{jnks_repository_name}")
             if yes_or_no("Do you want to create Jenkins Job?", default=True):
-                jnks.create_job(jnks_group_name, jnks_repository_name, self.project_name)
+                jnks.create_job(jnks_group_name, jnks_repository_name, self.project_name, gitlab_url)
                 cprint(f"Jenkins job created: {jnks_group_name}/{jnks_repository_name}", "green")
 
     def create_sonarqube(self, group_name, repository_name, sq_config):
